# coding: utf-8

"""
    MoneyBox

    MoneyBox will help you better understand your finances, improve financial literacy, and achieve financial goals.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, conlist

class PatchedGroup(BaseModel):
    """
    PatchedGroup
    """
    id: Optional[StrictInt] = None
    created_at: Optional[datetime] = Field(None, description="Date and time of creation")
    updated_at: Optional[datetime] = Field(None, description="Date and time of last update")
    is_deleted: Optional[StrictBool] = None
    members: Optional[conlist(StrictInt)] = Field(None, description="Members of the group")
    __properties = ["id", "created_at", "updated_at", "is_deleted", "members"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PatchedGroup:
        """Create an instance of PatchedGroup from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "id",
                            "created_at",
                            "updated_at",
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PatchedGroup:
        """Create an instance of PatchedGroup from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PatchedGroup.parse_obj(obj)

        _obj = PatchedGroup.parse_obj({
            "id": obj.get("id"),
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at"),
            "is_deleted": obj.get("is_deleted"),
            "members": obj.get("members")
        })
        return _obj


