class Currency:
    RUB = ("RUB", "Рубль")
    USD = ("USD", "Доллар")
    EUR = ("EUR", "Евро")


DEFAULT_EXPENSE_CATEGORY = [
    "Авто",
    "Благотворительность",
    "Бытовая техника",
    "Дача",
    "Дети",
    "Долги",
    "Домашние животные",
    "ЖКХ",
    "Кредит",
    "Медицина",
    "Образование",
    "Одежда и обувь",
    "Питание",
    "Подарки",
    "Прочее",
    "Развлечения",
    "Ремонт",
    "Связь",
    "Страхование",
    "Транспорт",
]

DEFAULT_INCOME_CATEGORY = [
    "Аванс",
    "Алименты",
    "Банковские проценты",
    "Возврат налогов",
    "Возврат платежа",
    "Дивиденты",
    "Доход от бизнеса",
    "Зарплата",
    "Командировочные",
    "Отпускные",
    "Пенсия",
    "Подарки",
    "Подработка",
    "Помощь",
    "Премия",
    "Приз(выигрыш)",
    "Продажа вещей",
    "Социальное пособие",
    "Стипендия",
]
WALLET_LIST = [
    "Карта",
    "Наличные",
    "Счет",
]

RUB_NAME = "Российский рубль"
