# coding: utf-8

"""
    MoneyBox

    MoneyBox will help you better understand your finances, improve financial literacy, and achieve financial goals.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.api.incomes_api import IncomesApi  # noqa: E501


class TestIncomesApi(unittest.TestCase):
    """IncomesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IncomesApi()  # noqa: E501

    def tearDown(self) -> None:
        pass

    def test_income_create(self) -> None:
        """Test case for income_create

        """
        pass

    def test_income_destroy(self) -> None:
        """Test case for income_destroy

        """
        pass

    def test_income_list(self) -> None:
        """Test case for income_list

        """
        pass

    def test_income_partial_update(self) -> None:
        """Test case for income_partial_update

        """
        pass

    def test_income_retrieve(self) -> None:
        """Test case for income_retrieve

        """
        pass

    def test_income_update(self) -> None:
        """Test case for income_update

        """
        pass

    def test_incomecategory_create(self) -> None:
        """Test case for incomecategory_create

        """
        pass

    def test_incomecategory_destroy(self) -> None:
        """Test case for incomecategory_destroy

        """
        pass

    def test_incomecategory_list(self) -> None:
        """Test case for incomecategory_list

        """
        pass

    def test_incomecategory_partial_update(self) -> None:
        """Test case for incomecategory_partial_update

        """
        pass

    def test_incomecategory_retrieve(self) -> None:
        """Test case for incomecategory_retrieve

        """
        pass

    def test_incomecategory_update(self) -> None:
        """Test case for incomecategory_update

        """
        pass


if __name__ == '__main__':
    unittest.main()
